@@ -1,12 +1,11 @@
 use anyhow::Result;
 
-mod file_enumerator;
-mod consumer;
+mod filescanner;
 mod dionysos;
 mod yara_scanner;
 mod filename_scanner;
-mod stdout_printer;
 mod scanner_result;
+mod levenshtein_scanner;
 use dionysos::*;
 
 fn main() -> Result <()> {
